class Calc:

    def add(self, x, y):
        return x+y

    def product(self, x, y):
        return x*y

    def exponent(self, x, y):
        return x**y

    @staticmethod
    def power(x):
        return x**2
