# Jakaś zmienna
test = "wartość"

# Jakaś funkcja
def func():
    print("Jestem funkcją.")

# Jakaś klasa
class Klasa:
    def pisze(self):
        print("Jestem klasą.")

print(__name__)
if __name__ == "__main__":
    # Jakiś print
    print("Napis")
