from setuptools import setup, find_packages

setup(
    name="pytwwa5",
    version='0.7',
    packages=find_packages(),
    description="Our first Python distribution package",
    author="Unknown",
    author_email = "unknown@gmail.com"
)
